/**
 * Behavior for 'aggrid_widget_type' widget.
 */
(function ($) {
    'use strict';

    Drupal.aggridInstances = [];

    Drupal.behaviors.aggridIntegration = {
        attach: function (context) {
            function makeJson() {
                var aggridOutput = {};
                aggridOutput = gridOptions.rowData;

                // Write back to Drupal "Value" field
                $('#' + aggridFieldName +'_rowData').val(JSON.stringify(aggridOutput));
            }

            function formatNumber(number) {
                // this puts commas into the number eg 1000 goes to 1,000,
                // i pulled this from stack overflow, i have no idea how it works
                return Math.floor(number).toString().replace(/(\d)(?=(\d{3})+(?!\d))/g, "$1,");
            }

            // @todo Init functionality should support multiple drop zones on page.
            var selector = $('.aggrid-widget');

            var aggridFieldName = selector.data('target');
            var aggridLicense = selector.data('license');
            var aggridDataEdit = selector.data('edit') != undefined ? selector.data('edit') : false;

            selector.addClass('aggrid');

            $(selector)
                .css('height', '500px');

            // If DropzoneJS instance is already registered on Element. There is no
            // need to register it again.
            if (selector.once('.aggrid-widget').length !== selector.length) {
                return;
            }

            // Get the data
            var colDefsValue = $('#' + aggridFieldName +'_columnDefs').val();
            var rowDataValue = $('#' + aggridFieldName +'_rowData').val();
            var addOptValue = $('#' + aggridFieldName +'_addOptions').val();

            // If it's not blank, parse the json... otherwise, null
            var aggridJSON_colDefs = colDefsValue ? JSON.parse(colDefsValue) : null;
            var aggridJSON_rowData = rowDataValue ? JSON.parse(rowDataValue) : null;
            var aggridJSON_addOpt = addOptValue ? JSON.parse(addOptValue) : null;

            // Build JSON for ag-Grid
            var aggridJSON = {
                "columnDefs": aggridJSON_colDefs,
                "rowData": aggridJSON_rowData
            };
            aggridJSON = Object.assign(aggridJSON, aggridJSON_addOpt);

            // Default Options for all ag-Grid
            var default_gridOptions = {
                stopEditingWhenGridLosesFocus: true,
                defaultColDef: {
                    editable: aggridDataEdit,
                },
                onGridReady: function () {
                    gridOptions.api.sizeColumnsToFit();
                },
                onCellValueChanged: function() {
                    makeJson();
                }
            };

            //colDef.menuTabs: ['filterMenuTab','columnsMenuTab'],

            // Add the Default Options
            var gridOptions = aggridJSON;
            gridOptions = Object.assign(aggridJSON, default_gridOptions);


            // Apply the license if it is available
            if (aggridLicense != ''){
                agGrid.LicenseManager.setLicenseKey(aggridLicense);
            }

            // Get the ag-Grid Div and start it up
            var eGridDiv = document.querySelector('.aggrid-widget');
            // create the grid passing in the div to use together with the columns & data we want to use
            new agGrid.Grid(eGridDiv, gridOptions);
        }
    }

})(jQuery);
